@@ -8,7 +8,9 @@ import csv
 import datetime
 import logging
 import os
+import pathlib
 import re
+import shutil
 import sys
 from locale import LC_NUMERIC, atof, setlocale
 
@@ -42,7 +44,16 @@ def write_output_file(output_content, output_file):
 
 
 def pad_output_value(val, output_format, length):
-    if output_format in ("Integer", "Decimal", "Keep numeric"):
+    if (
+        output_format
+        in (
+            "Integer",
+            "Decimal",
+            "Keep numeric",
+            "Time",
+        )
+        or output_format.startswith("Date (")
+    ):
         # Numbers get padded with 0's added in front (to the left)
         val = str(val).zfill(length)
     else:
@@ -434,10 +445,36 @@ def validate_divert(divert):
     return divert_values
 
 
+def validate_input_output_args(args):
+    if args.input:
+        if not os.path.isfile(args.input):
+            logging.critical("The specified input file does not exist. Exiting...")
+            sys.exit(10)
+    elif args.input_directory:
+        if not args.output_directory:
+            logging.critical(
+                "The `--output_directory` argument must be specified in addition to "
+                "the `--input_directory` argument. Exiting..."
+            )
+            sys.exit(32)
+        if not os.path.isdir(args.input_directory):
+            logging.critical(
+                "The value passed as `--input-directory` argument is not a valid "
+                "folder path. Exiting..."
+            )
+            sys.exit(33)
+        if not os.path.isdir(args.output_directory):
+            pathlib.Path(args.output_directory).mkdir(parents=True, exist_ok=True)
+
+
 def validate_shared_args(args):
-    if not os.path.isfile(args.input):
-        logging.critical("The specified input file does not exist. Exiting...")
-        sys.exit(10)
+    validate_input_output_args(args)
+    if args.move_input_files and not args.output_directory:
+        logging.critical(
+            "The `--move-input-files` argument can only be used in combination with "
+            "the `--output-directory` argument. Exiting..."
+        )
+        sys.exit(35)
     if not os.path.isfile(args.config):
         logging.critical("The specified configuration file does not exist. Exiting...")
         sys.exit(12)
@@ -470,8 +507,33 @@ def validate_shared_args(args):
 
 
 def add_shared_args(parser):
+    input_group = parser.add_mutually_exclusive_group(required=True)
+    input_group.add_argument(
+        "-i", "--input", help="Specify the input file", action="store"
+    )
+    input_group.add_argument(
+        "-id",
+        "--input-directory",
+        help="Specify the input directory from which to process input files",
+        action="store",
+    )
+    output_group = parser.add_mutually_exclusive_group(required=True)
+    output_group.add_argument(
+        "-o", "--output", help="Specify the output file", action="store"
+    )
+    output_group.add_argument(
+        "-od",
+        "--output-directory",
+        help="The directory in which to create the output files",
+        action="store",
+    )
     parser.add_argument(
-        "-i", "--input", help="Specify the input file", action="store", required=True
+        "-m",
+        "--move-input-files",
+        help="Move the input files to the output directory after processing. Must be "
+        "used in conjunction with the `--output-directory` argument.",
+        action="store_true",
+        required=False,
     )
     parser.add_argument(
         "-c",
@@ -556,9 +618,6 @@ def parse_args(arguments):
         version="%s %s" % ("%(prog)s", get_version("__init__.py")),
     )
 
-    parser.add_argument(
-        "-o", "--output", help="Specify the output file", action="store", required=True
-    )
     parser.add_argument(
         "-x",
         "--overwrite-file",
@@ -594,12 +653,24 @@ def parse_args(arguments):
         args.logging_level = logging.getLevelName(args.loglevel)
 
     # Validate if the arguments are used correctly
-    if os.path.isfile(args.output) and not args.overwrite_file:
+    if args.output and os.path.isfile(args.output) and not args.overwrite_file:
         logging.critical(
             "The specified output file does already exist, will NOT overwrite. Add "
             "the `--overwrite-file` argument to allow overwriting. Exiting..."
         )
         sys.exit(11)
+    if args.overwrite_file and not args.output:
+        logging.critical(
+            "The `--overwrite-file` argument can only be used in combination with "
+            "the `--output` argument. Exiting..."
+        )
+        sys.exit(34)
+    if args.input and not args.output:
+        logging.critical(
+            "The `--output` argument must be specified in addition to the "
+            "`--input` argument. Exiting..."
+        )
+        sys.exit(31)
     validate_shared_args(args)
 
     logging.debug("These are the parsed arguments:\n'%s'" % args)
@@ -674,19 +745,37 @@ def init():
         # Parse the provided command-line arguments
         args = parse_args(sys.argv[1:])
 
-        process(
-            args.input,
-            args.output,
-            args.config,
-            args.delimiter,
-            args.quotechar,
-            args.skip_header,
-            args.skip_footer,
-            None,
-            args.locale,
-            args.truncate,
-            args.divert,
-        )
+        input_output_files = []
+        if args.input:
+            # Just a single input/output files combination
+            input_output_files = [(args.input, args.output)]
+        elif args.input_directory:
+            # Process all files in that top-level directory (no subdirectories)
+            (_, _, filenames) = next(os.walk(args.input_directory))
+            for ifile in filenames:
+                input_file = os.path.join(args.input_directory, ifile)
+                output_file = os.path.join(
+                    args.output_directory, "%s_processed%s" % (os.path.splitext(ifile))
+                )
+                input_output_files.append((input_file, output_file))
+
+        for (input_file, output_file) in input_output_files:
+            logging.info("Processing input file %s", input_file)
+            process(
+                input_file,
+                output_file,
+                args.config,
+                args.delimiter,
+                args.quotechar,
+                args.skip_header,
+                args.skip_footer,
+                None,
+                args.locale,
+                args.truncate,
+                args.divert,
+            )
+            if args.move_input_files:
+                shutil.move(input_file, args.output_directory)
 
 
 init()
